@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 University Corporation for Atmospheric Research
+ * Copyright 2014 University Corporation for Atmospheric Research
  *
  * This file is part of the UDUNITS-2 package.  See the file COPYRIGHT
  * in the top-level source-directory of the package for copying and
@@ -23,7 +23,7 @@
 
 #include "udunits2.h"
 
-static const char*  xmlPath;
+static const char*      xmlPath;
 static ut_system*	unitSystem;
 static ut_unit*		kilogram;
 static ut_unit*		meter;
@@ -322,9 +322,13 @@ test_utToString(void)
     CU_ASSERT_PTR_NOT_NULL(unit);
     CU_ASSERT(ut_format(unit, buf, sizeof(buf), asciiSymbolDef) != -1);
     CU_ASSERT_STRING_EQUAL(buf, string);
+    if (strcmp(buf, string))
+        printf("%d: buf=%s\n", __LINE__, buf);
 
     n = ut_format(unit, buf, 1, asciiSymbolDef);
     CU_ASSERT_EQUAL(n, strlen(string));
+    if (n != strlen(string))
+        printf("%d: n=%d\n", __LINE__, n);
     ut_free(unit);
 }
 
@@ -1108,9 +1112,9 @@ test_utAreConvertible(void)
     CU_ASSERT_EQUAL(ut_are_convertible(secondsSinceTheEpoch,
 	secondsSinceTheEpoch), 1);
     CU_ASSERT_EQUAL(ut_are_convertible(secondsSinceTheEpoch, second), 0);
-    CU_ASSERT_EQUAL(ut_are_convertible(joulePerKilogram, 
+    CU_ASSERT_EQUAL(ut_are_convertible(joulePerKilogram,
 	meterSquaredPerSecondSquared), 1);
-    CU_ASSERT_EQUAL(ut_are_convertible(joulePerKilogram, 
+    CU_ASSERT_EQUAL(ut_are_convertible(joulePerKilogram,
 	meterPerSecondSquared), 0);
 
     unit = ut_raise(radian, 2);
@@ -1191,14 +1195,14 @@ test_utGetConverter(void)
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats, 1, floats+1), floats+1);
     CU_ASSERT_EQUAL(floats[1], 0);
     doubles[0] = 0; doubles[1] = 1000;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1),
 	doubles+1);
     CU_ASSERT_EQUAL(doubles[1], 0);
     floats[0] = 0; floats[1] = 1000;
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats+1, 1, floats), floats);
     CU_ASSERT_EQUAL(floats[0], 1);
     doubles[0] = 0; doubles[1] = 1000;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles),
 	doubles);
     CU_ASSERT_EQUAL(doubles[0], 1);
     cv_free(converter);
@@ -1218,14 +1222,14 @@ test_utGetConverter(void)
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats, 1, floats+1), floats+1);
     CU_ASSERT_EQUAL(floats[1], 0);
     doubles[0] = 0; doubles[1] = 1;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1),
 	doubles+1);
     CU_ASSERT_EQUAL(doubles[1], 0);
     floats[0] = 0; floats[1] = 1;
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats+1, 1, floats), floats);
     CU_ASSERT_EQUAL(floats[0], 1000);
     doubles[0] = 0; doubles[1] = 1;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles),
 	doubles);
     CU_ASSERT_EQUAL(doubles[0], 1000);
     cv_free(converter);
@@ -1245,14 +1249,14 @@ test_utGetConverter(void)
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats, 1, floats+1), floats+1);
     CU_ASSERT_TRUE(areCloseFloats(floats[1], -273.15));
     doubles[0] = 0; doubles[1] = 273.15;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1),
 	doubles+1);
     CU_ASSERT_EQUAL(doubles[1], -273.15);
     floats[0] = 0; floats[1] = 273.15;
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats+1, 1, floats), floats);
     CU_ASSERT_TRUE(areCloseFloats(floats[0], 0));
     doubles[0] = 0; doubles[1] = 273.15;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles),
 	doubles);
     CU_ASSERT_EQUAL(doubles[0], 0);
     cv_free(converter);
@@ -1272,14 +1276,14 @@ test_utGetConverter(void)
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats, 1, floats+1), floats+1);
     CU_ASSERT_TRUE(areCloseFloats(floats[1], 273.15));
     doubles[0] = 0; doubles[1] = -273.15;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1),
 	doubles+1);
     CU_ASSERT_EQUAL(doubles[1], 273.15);
     floats[0] = 0; floats[1] = -273.15;
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats+1, 1, floats), floats);
     CU_ASSERT_TRUE(areCloseFloats(floats[0], 0));
     doubles[0] = 0; doubles[1] = -273.15;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles),
 	doubles);
     CU_ASSERT_EQUAL(doubles[0], 0);
     cv_free(converter);
@@ -1299,14 +1303,14 @@ test_utGetConverter(void)
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats, 1, floats+1), floats+1);
     CU_ASSERT_TRUE(areCloseFloats(floats[1], 32));
     doubles[0] = 0; doubles[1] = 100;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1),
 	doubles+1);
     CU_ASSERT_TRUE(areCloseDoubles(doubles[1], 32));
     floats[0] = 0; floats[1] = 100;
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats+1, 1, floats), floats);
     CU_ASSERT_TRUE(areCloseFloats(floats[0], 212));
     doubles[0] = 0; doubles[1] = 100;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles),
 	doubles);
     CU_ASSERT_TRUE(areCloseDoubles(doubles[0], 212));
     cv_free(converter);
@@ -1326,14 +1330,14 @@ test_utGetConverter(void)
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats, 1, floats+1), floats+1);
     CU_ASSERT_TRUE(areCloseFloats(floats[1], 0));
     doubles[0] = 32; doubles[1] = 212;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1),
 	doubles+1);
     CU_ASSERT_TRUE(areCloseDoubles(doubles[1], 0));
     floats[0] = 32; floats[1] = 212;
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats+1, 1, floats), floats);
     CU_ASSERT_TRUE(areCloseFloats(floats[0], 100));
     doubles[0] = 32; doubles[1] = 212;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles),
 	doubles);
     CU_ASSERT_TRUE(areCloseDoubles(doubles[0], 100));
     cv_free(converter);
@@ -1358,14 +1362,14 @@ test_utGetConverter(void)
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats, 1, floats+1), floats+1);
     CU_ASSERT_TRUE(areCloseFloats(floats[1], 10));
     doubles[0] = 10; doubles[1] = 1000;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1),
 	doubles+1);
     CU_ASSERT_TRUE(areCloseDoubles(doubles[1], 10));
     floats[0] = 10; floats[1] = 1000;
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats+1, 1, floats), floats);
     CU_ASSERT_TRUE(areCloseFloats(floats[0], 30));
     doubles[0] = 10; doubles[1] = 1000;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles),
 	doubles);
     CU_ASSERT_TRUE(areCloseDoubles(doubles[0], 30));
     cv_free(converter);
@@ -1388,14 +1392,14 @@ test_utGetConverter(void)
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats, 1, floats+1), floats+1);
     CU_ASSERT_TRUE(areCloseFloats(floats[1], 10));
     doubles[0] = 10; doubles[1] = 30;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1),
 	doubles+1);
     CU_ASSERT_TRUE(areCloseDoubles(doubles[1], 10));
     floats[0] = 10; floats[1] = 30;
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats+1, 1, floats), floats);
     CU_ASSERT_TRUE(areCloseFloats(floats[0], 1000));
     doubles[0] = 10; doubles[1] = 30;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles),
 	doubles);
     CU_ASSERT_TRUE(areCloseDoubles(doubles[0], 1000));
     cv_free(converter);
@@ -1460,6 +1464,8 @@ test_utOffsetByTime(void)
     CU_ASSERT_TRUE_FATAL(nchar < sizeof(buf));
     buf[nchar] = 0;
     CU_ASSERT_STRING_EQUAL(buf, "s @ 19700101T000000.0000000 UTC");
+    if (strcmp(buf, "s @ 19700101T000000.0000000 UTC"))
+        fprintf(stderr, "buf=%s\n", buf);
 
     minutesSinceTheMillenium =
         ut_offset_by_time(minute, ut_encode_time(2001, 1, 1, 0, 0, 0));
@@ -1486,14 +1492,14 @@ test_utOffsetByTime(void)
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats, 1, floats+1), floats+1);
     CU_ASSERT_TRUE(areCloseFloats(floats[1], 0));
     doubles[0] = 0; doubles[1] = 1000;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1),
 	doubles+1);
     CU_ASSERT_TRUE(areCloseDoubles(doubles[1], 0));
     floats[0] = 0; floats[1] = 1000;
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats+1, 1, floats), floats);
     CU_ASSERT_TRUE(areCloseFloats(floats[0], 1000));
     doubles[0] = 0; doubles[1] = 1000;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles),
 	doubles);
     CU_ASSERT_TRUE(areCloseDoubles(doubles[0], 1000));
     cv_free(converter);
@@ -1524,14 +1530,14 @@ test_utOffsetByTime(void)
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats, 1, floats+1), floats+1);
     CU_ASSERT_TRUE(areCloseFloats(floats[1], 0));
     doubles[0] = 0; doubles[1] = 86400;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1),
 	doubles+1);
     CU_ASSERT_TRUE(areCloseDoubles(doubles[1], 0));
     floats[0] = 0; floats[1] = 86400;
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats+1, 1, floats), floats);
     CU_ASSERT_TRUE(areCloseFloats(floats[0], 1));
     doubles[0] = 0; doubles[1] = 86400;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles),
 	doubles);
     CU_ASSERT_TRUE(areCloseDoubles(doubles[0], 1));
     cv_free(converter);
@@ -1551,20 +1557,64 @@ test_utOffsetByTime(void)
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats, 1, floats+1), floats+1);
     CU_ASSERT_TRUE(areCloseFloats(floats[1], 0));
     doubles[0] = 0; doubles[1] = 1;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles, 1, doubles+1),
 	doubles+1);
     CU_ASSERT_TRUE(areCloseDoubles(doubles[1], 0));
     floats[0] = 0; floats[1] = 1;
     CU_ASSERT_EQUAL(cv_convert_floats(converter, floats+1, 1, floats), floats);
     CU_ASSERT_TRUE(areCloseFloats(floats[0], 86400));
     doubles[0] = 0; doubles[1] = 1;
-    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles), 
+    CU_ASSERT_EQUAL(cv_convert_doubles(converter, doubles+1, 1, doubles),
 	doubles);
     CU_ASSERT_TRUE(areCloseDoubles(doubles[0], 86400));
     cv_free(converter);
 
     ut_free(daysSinceTheEpoch);
 
+    {
+        /*
+         * "Naked hour" test
+         */
+        ut_unit* unit = ut_parse(unitSystem,
+                "second since 1970-01-01 0", UT_ASCII);
+        CU_ASSERT_PTR_NOT_NULL(unit);
+        if (unit) {
+            converter = ut_get_converter(unit, secondsSinceTheEpoch);
+            CU_ASSERT_PTR_NOT_NULL(converter);
+            if (converter) {
+                CU_ASSERT_TRUE(areCloseDoubles(cv_convert_double(converter, 0), 0));
+                cv_free(converter);
+            }
+            ut_free(unit);
+        }
+
+        unit = ut_parse(unitSystem,
+                "second since 1970-01-01 0+1", UT_ASCII);
+        CU_ASSERT_PTR_NOT_NULL(unit);
+        if (unit) {
+            converter = ut_get_converter(unit, secondsSinceTheEpoch);
+            CU_ASSERT_PTR_NOT_NULL(converter);
+            if (converter) {
+                CU_ASSERT_TRUE(areCloseDoubles(cv_convert_double(converter, 0), -3600));
+                cv_free(converter);
+            }
+            ut_free(unit);
+        }
+
+        unit = ut_parse(unitSystem,
+                "second since 1970-01-01 0 -1", UT_ASCII);
+        CU_ASSERT_PTR_NOT_NULL(unit);
+        if (unit) {
+            converter = ut_get_converter(unit, secondsSinceTheEpoch);
+            CU_ASSERT_PTR_NOT_NULL(converter);
+            if (converter) {
+                CU_ASSERT_TRUE(areCloseDoubles(cv_convert_double(converter, 0), 3600));
+                cv_free(converter);
+            }
+            ut_free(unit);
+        }
+    }
+
     CU_ASSERT_PTR_NULL(ut_offset_by_time(NULL, ut_encode_time(0, 0, 0, 0, 0, 0)));
     CU_ASSERT_EQUAL(ut_get_status(), UT_BAD_ARG);
 }
@@ -1594,8 +1644,22 @@ test_ut_decode_time(void)
     CU_ASSERT_EQUAL(minute1, minute2);
     CU_ASSERT_EQUAL(second1, second2);
     CU_ASSERT_EQUAL(resolution1, resolution2);
-}
 
+    /*
+     * User reported getting 60 seconds back from ut_decode_time() for a time
+     * value of -3240.0.
+     */
+    //timeval = ut_encode_time(2000, 12, 31, 23, 5, 60);
+    timeval = -3240.0;
+    ut_decode_time(timeval, &year2, &month2, &day2, &hour2, &minute2,
+        &second2, &resolution2);
+    CU_ASSERT_EQUAL(year2, 2000);
+    CU_ASSERT_EQUAL(month2, 12);
+    CU_ASSERT_EQUAL(day2, 31);
+    CU_ASSERT_EQUAL(hour2, 23);
+    CU_ASSERT_EQUAL(minute2, 6);
+    CU_ASSERT_EQUAL(second2, 0);
+}
 
 
 static void
@@ -1755,6 +1819,32 @@ test_parsing(void)
     CU_ASSERT_EQUAL(ut_compare(unit, kilometer), 0);
     ut_free(unit);
 
+    spec = "1/2";
+    unit = ut_parse(unitSystem, spec, UT_ASCII);
+    CU_ASSERT_PTR_NOT_NULL(unit);
+    CU_ASSERT_EQUAL(ut_are_convertible(unit,
+            ut_get_dimensionless_unit_one(unitSystem)), 1);
+    ut_free(unit);
+
+    spec = "1/(2)";
+    unit = ut_parse(unitSystem, spec, UT_ASCII);
+    CU_ASSERT_PTR_NOT_NULL(unit);
+    CU_ASSERT_EQUAL(ut_are_convertible(unit,
+            ut_get_dimensionless_unit_one(unitSystem)), 1);
+    ut_free(unit);
+
+    spec = "1/m";
+    unit = ut_parse(unitSystem, spec, UT_ASCII);
+    CU_ASSERT_PTR_NOT_NULL(unit);
+    CU_ASSERT_EQUAL(ut_are_convertible(unit, meter), 1);
+    ut_free(unit);
+
+    spec = "1/(2 m)";
+    unit = ut_parse(unitSystem, spec, UT_ASCII);
+    CU_ASSERT_PTR_NOT_NULL(unit);
+    CU_ASSERT_EQUAL(ut_are_convertible(unit, meter), 1);
+    ut_free(unit);
+
     spec = "(K/1.8) @ 459.67";
     unit = ut_parse(unitSystem, spec, UT_ASCII);
     CU_ASSERT_EQUAL(ut_are_convertible(unit, fahrenheit), 1);
@@ -1832,6 +1922,12 @@ test_parsing(void)
     CU_ASSERT_EQUAL(ut_compare(unit, secondsSinceTheEpoch), 0);
     ut_free(unit);
 
+    spec = "second ref 1970-01-01T00:00:00Z";
+    unit = ut_parse(unitSystem, spec, UT_ASCII);
+    CU_ASSERT_PTR_NOT_NULL(unit);
+    CU_ASSERT_EQUAL(ut_compare(unit, secondsSinceTheEpoch), 0);
+    ut_free(unit);
+
     spec = "kg\xb7m\xb2/s\xb3"; /* "kg" mid-dot "m" squared "/" "s" cubed */
     unit = ut_parse(unitSystem, spec, UT_LATIN1);
     CU_ASSERT_PTR_NOT_NULL(unit);
@@ -1930,9 +2026,9 @@ test_xml(void)
     int                 status;
     ut_unit*            unit1;
     ut_unit*            unit2;
-    cv_converter*	    converter;
-    char*		        spec;
-    ut_unit*		    unit;
+    cv_converter*	converter;
+    char*		spec;
+    ut_unit*		unit;
 
     ut_set_error_message_handler(ut_write_to_stderr);
     xmlSystem = ut_read_xml(xmlPath);
@@ -2156,9 +2252,60 @@ test_xml(void)
     ut_free_system(xmlSystem);
 }
 
+static void
+test_mm2_day2_divide(void)
+{
+    ut_system*  xmlSystem;
+    ut_unit*    unit1;
+    ut_unit*    unit2;
+    const char* spec = "mm2 day-2";
+
+    ut_set_error_message_handler(ut_write_to_stderr);
+    xmlSystem = ut_read_xml(xmlPath);
+    CU_ASSERT_PTR_NOT_NULL_FATAL(xmlSystem);
+
+    unit1 = ut_parse(xmlSystem, spec, UT_ASCII);
+    CU_ASSERT_PTR_NOT_NULL(unit1);
+    unit2 = ut_divide(unit1, unit1);
+
+    const char* expect = "1";
+    char        actual[128];
+    ut_format(unit2, actual, 128, UT_ASCII);
+    CU_ASSERT_STRING_EQUAL(actual, expect);
+    if (strcmp(actual, expect))
+        fprintf(stderr, "(%s)/(%s) = \"%s\"\n", spec, spec, actual);
+
+    ut_free(unit1);
+    ut_free(unit2);
+    ut_free_system(xmlSystem);
+}
+
+
+test_timeResolution(void)
+{
+    ut_system*  xmlSystem;
+
+    ut_set_error_message_handler(ut_write_to_stderr);
+    xmlSystem = ut_read_xml(xmlPath);
+    CU_ASSERT_PTR_NOT_NULL_FATAL(xmlSystem);
+
+    // Maximum temporal resolution:
+    const char string[] = "day since 2001-01-01 00:00:00.000000000 UTC";
+    ut_unit* unit = ut_parse(xmlSystem, string, UT_ASCII);
+    CU_ASSERT_PTR_NOT_NULL_FATAL(unit);
+
+    char buf[128];
+    int  len = ut_format(unit, buf, sizeof(buf), UT_ASCII | UT_NAMES);
+    CU_ASSERT_NOT_EQUAL_FATAL(len, -1);
+    printf("test_timeResolution() unit=\"%s\"", buf);
+    CU_ASSERT_STRING_EQUAL(buf, string);
+
+    ut_free(unit);
+}
+
 int
 main(
-    const int		    argc,
+    const int           argc,
     const char* const*	argv)
 {
     int	exitCode = EXIT_FAILURE;
@@ -2171,6 +2318,7 @@ main(
 	CU_Suite*	testSuite = CU_add_suite(__FILE__, setup, teardown);
 
 	if (testSuite != NULL) {
+	    CU_ADD_TEST(testSuite, test_mm2_day2_divide);
 	    CU_ADD_TEST(testSuite, test_unitSystem);
 	    CU_ADD_TEST(testSuite, test_utNewBaseUnit);
 	    CU_ADD_TEST(testSuite, test_utNewDimensionlessUnit);
@@ -2206,6 +2354,7 @@ main(
 	    CU_ADD_TEST(testSuite, test_parsing);
 	    CU_ADD_TEST(testSuite, test_visitor);
 	    CU_ADD_TEST(testSuite, test_xml);
+	    CU_ADD_TEST(testSuite, test_timeResolution);
 	    /*
 	    */
 
