@@ -18,24 +18,45 @@
 #   define _XOPEN_SOURCE 500
 #endif
 
+#if defined(__linux__)
+#   ifndef _GNU_SOURCE
+#       define _GNU_SOURCE
+#   endif
+#endif
+
 #include <assert.h>
 #include <errno.h>
 #include <fcntl.h>
+#ifndef _MSC_VER
 #include <libgen.h>
+#endif
 #include <limits.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#ifndef _MSC_VER
 #include <strings.h>
 #include <unistd.h>
+#endif
 #include <sys/stat.h>
 #include <sys/types.h>
+#if defined(__linux__)
+#include <dlfcn.h>
+#elif defined(__APPLE__)
+#define _DARWIN_C_SOURCE
+#include <dlfcn.h>
+#elif defined _WIN32
+#include <windows.h>
+#endif
 
+#ifndef DLL_UDUNITS2
+#define XML_STATIC
+#endif
 #include "expat.h"
 #include "udunits2.h"
 
 #ifndef _XOPEN_PATH_MAX
-#   define _XOPEN_PATH_MAX 1024
+#   define _XOPEN_PATH_MAX 1024 // Includes terminating NUL
 #endif
 
 #define NAME_SIZE 128
@@ -90,7 +111,7 @@ static ut_status readXml(
 static File*            currFile = NULL;
 static ut_system*	unitSystem = NULL;
 static char*            text = NULL;
-static size_t           nbytes = 0;
+static size_t           nbytes = 0; /// Number of characters excluding NUL
 
 
 /*
@@ -110,7 +131,7 @@ ut_form_plural(
     const char*	plural = NULL;		/* failure */
 
     if (singular != NULL) {
-        int     length = strlen(singular);
+        size_t length = strlen(singular);
 
 	if (length + 3 >= sizeof(buf)) {
             ut_set_status(UT_SYNTAX);
@@ -560,7 +581,7 @@ mapUnitToId(
  *
  * Arguments:
  *      unit            Pointer to the unit.
- *      id              Pointer to the identifier upon wich to base all
+ *      id              Pointer to the identifier upon which to base all
  *                      derived identifiers.
  *      encoding        The encoding of "id".
  *      isName          Whether or not "id" is a name.
@@ -603,7 +624,7 @@ mapUnitToIds(
  *
  * Arguments:
  *      unit            Pointer to the unit.
- *      name            Pointer to the name upon wich to base all derived names.
+ *      name            Pointer to the name upon which to base all derived names.
  *      encoding        The encoding of "name".
  * Returns:
  *      0               Failure.
@@ -624,7 +645,7 @@ mapUnitToNames(
  *
  * Arguments:
  *      unit            Pointer to the unit.
- *      symbol          Pointer to the symbol upon wich to base all derived
+ *      symbol          Pointer to the symbol upon which to base all derived
  *                      symbols.
  *      encoding        The encoding of "symbol".
  * Returns:
@@ -1518,7 +1539,7 @@ endSingular(
         XML_StopParser(currFile->parser, 0);
     }
     else {
-        (void)strcpy(currFile->singular, text);
+        (void)strncpy(currFile->singular, text, NAME_SIZE);
     }
 }
 
@@ -1566,7 +1587,7 @@ endPlural(
         XML_StopParser(currFile->parser, 0);
     }
     else {
-        (void)strcpy(currFile->plural, text);
+        (void)strncpy(currFile->plural, text, NAME_SIZE);
     }
 }
 
@@ -1793,7 +1814,13 @@ endImport(
         path = text;
     }
     else {
-        (void)snprintf(buf, sizeof(buf), "%s/%s",
+        (void)snprintf(buf, sizeof(buf),
+#ifdef _MSC_VER
+            // The directory pathname has a trailing backslash on Windows
+            "%s%s",
+#else
+            "%s/%s",
+#endif
             XML_GetBase(currFile->parser), text);
 
         buf[sizeof(buf)-1] = 0;
@@ -2063,12 +2090,24 @@ readXml(
         ut_handle_error_message("Couldn't create XML parser");
     }
     else {
-        char        base[_XOPEN_PATH_MAX];
-
-        (void)strncpy(base, path, sizeof(base));
-        base[sizeof(base)-1] = 0;
-        (void)memmove(base, dirname(base), sizeof(base));
-        base[sizeof(base)-1] = 0;
+        char base[_XOPEN_PATH_MAX];
+#ifdef _MSC_VER
+        {
+            char drive[_MAX_DRIVE+1]; // Will have trailing colon
+            char directory[_MAX_DIR+1]; // Will have trailing backslash
+            _splitpath(path, drive, directory, NULL, NULL);
+            (void)snprintf(base, sizeof(base), "%s%s", drive, directory);
+            base[sizeof(base)-1] = 0;
+        }
+#else
+        {
+            // Temporary buffer used because `dirname()` modifies its argument
+            char tmp[strlen(path)+1];
+            (void)strcpy(tmp, path);
+            (void)strncpy(base, dirname(tmp), sizeof(base));
+            base[sizeof(base)-1] = 0;
+        }
+#endif
 
         if (XML_SetBase(parser, base) != XML_STATUS_OK) {
             status = UT_OS;
@@ -2091,6 +2130,56 @@ readXml(
 }
 
 
+/* A bit hacky but much better than modifying binaries. */
+static const char*
+default_udunits2_xml_path()
+{
+    const char* path;
+    char const* soname = 0;
+
+#if defined(__APPLE__) || defined(__linux__)
+    #define END_BIT "/share/udunits/udunits2.xml"
+    #define SEP '/'
+    Dl_info info;
+    if (dladdr(default_udunits2_xml_path, &info))
+        soname = info.dli_fname;
+#elif defined(_WIN32)
+    #define END_BIT "\\share\\udunits\\udunits2.xml"
+    #define SEP '\\'
+    // NB: XP+ solution!
+    HMODULE hModule = NULL;
+    GetModuleHandleEx(GET_MODULE_HANDLE_EX_FLAG_FROM_ADDRESS,
+            (LPCTSTR)default_udunits2_xml_path, &hModule);
+    char tmpbuf[MAX_PATH * 4];
+    GetModuleFileName(hModule, &tmpbuf[0], MAX_PATH * 4);
+    soname = &tmpbuf[0];
+#endif
+    if (soname == NULL) {
+        path = DEFAULT_UDUNITS2_XML_PATH;
+    }
+    else {
+        static char result[PATH_MAX];
+
+        if (result[0] == 0) {
+            int prefixLen = strlen(soname);
+
+            if (soname[prefixLen-1] == SEP) {
+                --prefixLen;
+                if (soname[prefixLen-1] == SEP)
+                    --prefixLen;
+            }
+
+            snprintf(result, sizeof(result), "%.*s%s", prefixLen, soname,
+                    END_BIT);
+            result[sizeof(result)-1] = 0;
+        }
+
+        path = result;
+    }
+
+    return path;
+}
+
 /**
  * Returns the pathname of the XML database.
  *
@@ -2100,11 +2189,11 @@ readXml(
  *                  pathname specified by the environment variable
  *                  UDUNITS2_XML_PATH is returned if set; otherwise, the
  *                  compile-time pathname of the installed, default, unit
- *                  database is returned.
+ *                  database is returned. Caller must not free.
  */
 const char*
 ut_get_path_xml(
-	const char*	path,
+	const char* path,
 	ut_status*  status)
 {
     if (path != NULL) {
@@ -2117,7 +2206,7 @@ ut_get_path_xml(
         	*status = UT_OPEN_ENV;
     	}
     	else {
-          	path = DEFAULT_UDUNITS2_XML_PATH;
+          	path = default_udunits2_xml_path();
         	*status = UT_OPEN_DEFAULT;
     	}
     }
